@@ -10,7 +10,7 @@ if (any(hasattr(connection.ops, 'spatial_version')
     try:
         from django.contrib.gis.db.models import *
         from django.contrib.gis.db.models import GeoManager as Manager
-        from swingers.models.models import ActiveGeoModel as ActiveModel
+        from swingers.models.base import ActiveGeoModel as ActiveModel
         from swingers.models.managers import (ActiveGeoModelManager as
                                                    ActiveModelManager)
         GIS_ENABLED = True
