@@ -1,9 +1,24 @@
+import os
 
-DATABASES = {
-    'default': {
-        'ENGINE': 'django.db.backends.sqlite3'
+
+# are we postgis enabled?
+if os.environ.get('POSTGIS'):
+    DATABASES = {
+        'default': {
+            'NAME': 'swingers_test',
+            'USER': 'postgres',
+            'ENGINE': 'django.contrib.gis.db.backends.postgis',
+        },
     }
-}
+    GIS_ENABLED = True
+else:
+    DATABASES = {
+        'default': {
+            'ENGINE': 'django.db.backends.sqlite3'
+        }
+    }
+    GIS_ENABLED = False
+
 
 SITE_NAME = 'test'
 SITE_ID = 1
