@@ -1,9 +1,10 @@
-from .models import Duck
+from .models import Duck, Counter
 from swingers.views.decorators import (cancel_view_m, log_view_dec_m,
                                        log_view_dec)
 
 from django.http import HttpResponse
 from django.views.generic import CreateView
+from django.views.generic.edit import UpdateView
 from django.views.decorators.csrf import csrf_exempt
 
 
@@ -41,3 +42,8 @@ class CreateDuck2(CreateDuck):
     @log_view_dec_m(logger_name='test_view_stats')
     def get(self, request, *args, **kwargs):
         return super(CreateDuck2, self).get(request, *args, **kwargs)
+
+
+class CounterView(UpdateView):
+    template_name = "tests/dummy.html"
+    model = Counter
